'use strict';
/* global it, describe */
/** Imports */

require('./helper');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _vm = require('vm');

var _vm2 = _interopRequireDefault(_vm);

var _chai = require('chai');

var chai = _interopRequireWildcard(_chai);

var _babelCore = require('babel-core');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** Constants */
var babelOptions = {
  plugins: [_path2.default.join(__dirname, '../index.js')]
};

/** Helpers */
function runBabelInThisContext(code) {
  return _vm2.default.runInThisContext((0, _babelCore.transform)(code, babelOptions).code);
}

/** Init */
var expect = chai.expect;

/** Tests */

describe('pipeline operator', function () {
  it('should work', function () {
    (0, _babelCore.transform)('\n      ((user) => {\n        return user.name\n          |> capitalize\n          |> sayHello;\n      });\n    ', babelOptions);

    (0, _babelCore.transform)('\n      ((user) => {\n        return user.score\n          |> (_ => _ * 2)\n          |> (_ => _.toFixed(3));\n      });\n    ', babelOptions);

    (0, _babelCore.transform)('\n      (() => {\n        return (rootDir, filePath) => [rootDir, filePath]\n          |> ((args) => path.relative(...args))\n          |> path.dirname\n          |> ((res) => res.split(path.sep).join(path.posix.sep))\n          |> ((res) => \'/\' + (res === \'.\' ? \'\' : (res + \'/\')))\n          |> ((res) => res.replace(/@/g, \':\'));\n      });\n    ', babelOptions);
  });

  it('should return valid result', function () {
    var helloMessage = runBabelInThisContext('\n      (() => {\n        const user = { name: \'SuperPaintman\' };\n\n        function capitalize(str) {\n          return str.toUpperCase();\n        }\n\n        function sayHello(name) {\n          return \'Hello, \' + name + \'!\';\n        }\n\n        return user.name\n          |> capitalize\n          |> sayHello;\n      });\n    ')();

    expect(helloMessage).to.equal('Hello, SUPERPAINTMAN!');

    var doubleScore = runBabelInThisContext('\n      (() => {\n        const user = { score: 40.49138 };\n\n        return user.score\n          |> (_ => _ * 2)\n          |> (_ => _.toFixed(3))\n          |> parseFloat;\n      });\n    ')();

    expect(doubleScore).to.equal(80.983);

    var pathToUrl = runBabelInThisContext('\n      (({ path }) => {\n        return (rootDir, filePath) => [rootDir, filePath]\n          |> ((args) => path.relative(...args))\n          |> path.dirname\n          |> ((res) => res.split(path.sep).join(path.posix.sep))\n          |> ((res) => \'/\' + (res === \'.\' ? \'\' : (res + \'/\')))\n          |> ((res) => res.replace(/@/g, \':\'));\n      });\n    ')({ path: require('path') });

    expect(pathToUrl('./controllers', './controllers/api/users/index.js')).to.equal('/api/users/');

    expect(pathToUrl('./controllers', './controllers/index.js')).to.equal('/');
  });
});
//# sourceMappingURL=test.js.map